#!/usr/bin/python

"""
Script created by VND - Visual Network Description (SDN version)
"""
from mininet.net import Mininet
from mininet.node import Controller, RemoteController, OVSKernelSwitch, IVSSwitch, UserSwitch
from mininet.link import Link, TCLink
from mininet.cli import CLI
from mininet.log import setLogLevel

def topology():

    "Create a network."
    net = Mininet( controller=RemoteController, link=TCLink, switch=OVSKernelSwitch )

    print "*** Creating nodes"
    s1 = net.addSwitch( 's1', listenPort=6673, mac='00:00:00:00:00:01' )
    s2 = net.addSwitch( 's2', listenPort=6674, mac='00:00:00:00:00:02' )
    s3 = net.addSwitch( 's3', listenPort=6675, mac='00:00:00:00:00:03' )
    s4 = net.addSwitch( 's4', listenPort=6676, mac='00:00:00:00:00:04' )
    s5 = net.addSwitch( 's5', listenPort=6677, mac='00:00:00:00:00:05' )
    s6 = net.addSwitch( 's6', listenPort=6678, mac='00:00:00:00:00:06' )
    s7 = net.addSwitch( 's7', listenPort=6679, mac='00:00:00:00:00:07' )
    s8 = net.addSwitch( 's8', listenPort=66710, mac='00:00:00:00:00:08' )
    s9 = net.addSwitch( 's9', listenPort=66711, mac='00:00:00:00:00:09' )
    s10 = net.addSwitch( 's10', listenPort=66712, mac='00:00:00:00:00:10' )
    s11 = net.addSwitch( 's11', listenPort=66713, mac='00:00:00:00:00:11' )
    s12 = net.addSwitch( 's12', listenPort=66714, mac='00:00:00:00:00:12' )
    h33 = net.addHost( 'h33', mac='00:00:00:00:00:33', ip='10.0.0.33/8' )
    h34 = net.addHost( 'h34', mac='00:00:00:00:00:34', ip='10.0.0.34/8' )
    h35 = net.addHost( 'h35', mac='00:00:00:00:00:35', ip='10.0.0.35/8' )
    h36 = net.addHost( 'h36', mac='00:00:00:00:00:36', ip='10.0.0.36/8' )
    h37 = net.addHost( 'h37', mac='00:00:00:00:00:37', ip='10.0.0.37/8' )
    h38 = net.addHost( 'h38', mac='00:00:00:00:00:38', ip='10.0.0.38/8' )
    c48 = net.addController( 'c48', ip='127.0.0.1', port=6633 )

    print "*** Creating links"
    net.addLink(h35, s4)
    net.addLink(h38, s6)
    net.addLink(h34, s11)
    net.addLink(h33, s12)
    net.addLink(h37, s4)
    net.addLink(h35, s10)
    net.addLink(h36, s2)
    net.addLink(s8, s4)
    net.addLink(s11, s2)
    net.addLink(s7, s4)
    net.addLink(s10, s4)
    net.addLink(s8, s10)
    net.addLink(s8, s5)
    net.addLink(s5, s7)
    net.addLink(s3, s6)
    net.addLink(s11, s6)
    net.addLink(s1, s10)
    net.addLink(s8, s9)
    net.addLink(s2, s7)
    net.addLink(s3, s1)
    net.addLink(s8, s6)
    net.addLink(s5, s4)
    net.addLink(s12, s7)
    net.addLink(s12, s1)
    net.addLink(s5, s12)

    print "*** Starting network"
    net.build()
    c48.start()
    s4.start( [c48] )
    s10.start( [c48] )
    s2.start( [c48] )
    s9.start( [c48] )
    s8.start( [c48] )
    s1.start( [c48] )
    s11.start( [c48] )
    s6.start( [c48] )
    s7.start( [c48] )
    s3.start( [c48] )
    s5.start( [c48] )
    s12.start( [c48] )

    print "*** Running CLI"
    CLI( net )

    print "*** Stopping network"
    net.stop()

if __name__ == '__main__':
    setLogLevel( 'info' )
    topology()




