import sqlite3

class DataBase:

    def __init__(self, name):
        self.name = name

    def initialize_db(self):
        conn = sqlite3.connect(self.name)
        c = conn.cursor()
        c.execute('''CREATE TABLE IF NOT EXISTS   STA(PK           INT   PRIMARY KEY AUTOINCREMENT,
                                                      MAC          TEXT,
                                                      STATE        TEXT,
                                                      CONTEXT      BLOB,
                                                      BSSID        TEXT,
                                                      HISTORY      INT,
                                                      CON_TIME     DATETIME,
                                                      DIS_TIME     DATETIME);

                     CREATE TABLE IF NOT EXISTS   WTP(PK           INT   PRIMARY KEY AUTOINCREMENT,
                                                      MAC          REAL,
                                                      HISTORY      INT);

                     CREATE TABLE IF NOT EXISTS ASLAN(PK            INT   PRIMARY KEY AUTOINCREMENT,
                                                      TIME          REAL,
                                                      SRC_MAC       TEXT,
                                                      DST_MAC       TEXT,
                                                      SRC_IP        TEXT,
                                                      DST_IP        TEXT,
                                                      RSSI          INT,
                                                      STA_ID        INT,
                                                      WTP_ID        INT,
                                                      FOREIGN KEY(STA_ID) REFERENCES STA(PK),
                                                      FOREIGN KEY(WTP_ID) REFERENCES WTP(PK))''')
        c.close()
        conn.close()

    def write_to_wtp(self, mac, history):
        conn = sqlite3.connect(self.name)
        c = conn.cursor()
        c.execute("INSERT INTO WTP VALUES(NULL , ?, ?)", (mac, history))
        conn.commit()
        c.close()
        conn.close()

    def write_to_sta(self, mac, state, context, bssid, history, con_time, dis_time):
        conn = sqlite3.connect(self.name)
        c = conn.cursor()
        c.execute("INSERT INTO STA VALUES(NULL , ?, ?, ?, ?, ?, ?, ?)", (mac, state, context, bssid, history, con_time, dis_time))
        conn.commit()
        c.close()
        conn.close()

    def write_to_aslan(self, time, src_mac, dst_mac, src_ip, dst_ip, rssi, sta_id, wtp_id):
        conn = sqlite3.connect(self.name)
        c = conn.cursor()
        c.execute("INSERT INTO ASLAN VALUES(NULL , ?, ?, ?, ?, ?, ?, ?, ?)", (time, src_mac, dst_mac, src_ip, dst_ip, rssi, sta_id, wtp_id))
        conn.commit()
        c.close()
        conn.close()

    def read_from_wtp(self):
        conn = sqlite3.connect(self.name)
        c = conn.cursor()
        c.execute("SELECT * FROM WTP")
        conn.commit()
        c.close()
        conn.close()

    def read_from_sta(self):
        conn = sqlite3.connect(self.name)
        c = conn.cursor()
        c.execute("SELECT * FROM STA")
        conn.commit()
        c.close()
        conn.close()

    def read_from_aslan(self):
        conn = sqlite3.connect(self.name)
        c = conn.cursor()
        c.execute("SELECT * FROM ASLAN")
        conn.commit()
        c.close()
        conn.close()

    def custom_read_from_aslan(self):
        conn = sqlite3.connect(self.name)
        c = conn.cursor()
        c.execute("SELECT * FROM WTP")
        conn.commit()
        c.close()
        conn.close()

    def update_wtp(self, mac, history, pk):
        conn = sqlite3.connect(self.name)
        c = conn.cursor()
        c.execute("UPDATE WTP SET MAC = ?, HISTORY = ? WHERE PK = ?", (mac, history, pk))
        conn.commit()
        c.close()
        conn.close()

    def update_sta(self, mac, state, bssid, history, pk):
        conn = sqlite3.connect(self.name)
        c = conn.cursor()
        c.execute("UPDATE STA SET MAC = ?, STATE = ?, BSSID = ?, HISTORY = ? WHERE PK = ?", (mac, state, bssid, history, pk))
        conn.commit()
        c.close()
        conn.close()

    def delete_from_sta(self, pk):
        conn = sqlite3.connect(self.name)
        c = conn.cursor()
        c.execute("DELETE FROM STA WHERE PK = ?", pk)
        conn.commit()
        c.close()
        conn.close()

    def delete_from_wtp(self, pk):
        conn = sqlite3.connect(self.name)
        c = conn.cursor()
        c.execute("DELETE FROM WTP WHERE PK = ?", pk)
        conn.commit()
        c.close()
        conn.close()

    #nastavenie specialnych modov zapisovania/citania db (pragma)
    def set_database_mode(self):
        self